"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StageFacade = void 0;
const stateService_1 = require("./services/stateService");
const drop_1 = require("./useCases/drop");
const delete_1 = require("./useCases/delete");
const export_1 = require("./useCases/export");
const import_1 = require("./useCases/import");
const truncate_1 = require("./useCases/truncate");
const sync_1 = require("./useCases/sync");
const match_1 = require("./useCases/match");
const introspect_1 = require("./useCases/introspect");
class StageFacade {
    constructor(workspace, schemaState, expression, executor, languages, helper) {
        this.schemaState = schemaState;
        this.expression = expression;
        this.executor = executor;
        this.languages = languages;
        this.helper = helper;
        this.stageMappingService = new stateService_1.StageMappingService(workspace, schemaState, this.helper);
        this.stageModelService = new stateService_1.StageModelService(workspace, schemaState, this.helper);
    }
    exists(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const file = this.stageModelService.getFile(name);
            return this.helper.fs.exists(file);
        });
    }
    sync(options) {
        const _options = this.expression.solveQueryOptions(options);
        return new sync_1.StageSync(this.executor, this.stageModelService, this.schemaState, this.languages, _options, this.helper);
    }
    drop(options) {
        const _options = this.expression.solveQueryOptions(options);
        return new drop_1.StageDrop(this.executor, this.stageModelService, this.stageMappingService, this.schemaState, this.languages, _options, this.helper);
    }
    truncate(options) {
        const _options = this.expression.solveQueryOptions(options);
        return new truncate_1.StageTruncate(this.executor, this.stageModelService, this.schemaState, this.languages, _options, this.helper);
    }
    delete(options) {
        const _options = this.expression.solveQueryOptions(options);
        return new delete_1.StageDelete(this.stageMappingService, this.schemaState.domain, this.expression, this.executor, _options);
    }
    export(options) {
        const _options = this.expression.solveQueryOptions(options);
        return new export_1.StageExport(this.stageMappingService, this.schemaState.domain, this.expression, this.executor, _options);
    }
    import(options) {
        const _options = this.expression.solveQueryOptions(options);
        return new import_1.StageImport(this.stageMappingService, this.schemaState.domain, this.expression, this.executor, _options);
    }
    introspect(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const _options = this.expression.solveQueryOptions(options);
            return yield new introspect_1.StageIntrospect(this.executor, this.schemaState, this.languages, this.helper.schema, _options).execute();
        });
    }
    match() {
        return __awaiter(this, arguments, void 0, function* (options = { removeEntities: true, removeProperties: true, removeRelations: true }) {
            const _options = this.expression.solveQueryOptions(options);
            const mappings = yield this.introspect(_options);
            yield this.schemaState.updateFromMapping(mappings, _options);
            yield new match_1.StageMatch(this.executor, this.stageModelService, this.schemaState, this.languages, _options, this.helper).execute();
        });
    }
    syncAndImport(data, name, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const schemaData = yield this.schemaState.updateFromData(data, name);
            yield this.sync(options).execute();
            yield this.import(options).execute(schemaData);
            return schemaData;
        });
    }
}
exports.StageFacade = StageFacade;
//# sourceMappingURL=facade.js.map